import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';

//fetching the data
const csvUrl = [
  'https://gist.githubusercontent.com/codingcooper/350a662b384d585be60ac9234461369b/raw/e72a9ca9c679cd00ecdd11f2d0261dc60880c7a6/penguins.csv'
].join('');
const parseRow = (d) => {
  d.BodyMass = +d.BodyMass;
  d.CulmenDepth = +d.CulmenDepth;
  d.FlipperLength = +d.FlipperLength;
  d.CulmenLength = +d.CulmenLength;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);
//assigning our attributes data
const xValue = (d) => d.FlipperLength;
const yValue = (d) => d.CulmenLength;
const rxValue = (d) => d.BodyMass;
const ryValue = (d) => d.CulmenDepth;
const speciesValue = (d) => d.Species;
const colorValue = d => d.Species;
const colorLabel = 'Species:';

//given colors to our data
const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.CulmenLength);
  const y = yValue((d) => d.BodyMass);
  const marker = (d) => {
        	switch(d){
            case 'Adelie Penguin (Pygoscelis adeliae)':
              return 'steelblue';
            case 'Chinstrap penguin (Pygoscelis antarctica)':
              return 'gold';
            default:
              return 'darkgreen';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.CulmenLength),
          y: yValue((d) => d.BodyMass),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//Defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.CulmenLength)
    .yValue((d) => d.BodyMass)
    .margin({
      top: 50,
      right: 60,
      bottom: 95,
      left: 95,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);





//Defining the shape and structure of data points 
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

     
    
  
  const columns = [
    'CulmenLength',
    'CulmenDepth',
    'FlipperLength',
    'BodyMass',
  ];

  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]); 
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("fill", "3CA030")
    			.style("font-weight","bold")
          .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("Penguins Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

   
// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("Adelie Penguin").style("font-size", "15px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Chinstrap penguin").style("font-size", "15px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Gentoo penguin").style("font-size", "15px").attr("alignment-baseline","middle")
  
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("BodyMass");
    
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "steelblue")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "gold")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "darkgreen")
   // plot petal_width on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("CulmenLength");
     // plot sepal_width on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("CulmenDepth");
     // plot petal_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("FlipperLength");
     // plot BodyMass on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("BodyMass");
    i++;
  }, 2000);// For every 2 seconds It updates
};
main();



